==> saphire-1.1.1.tgz: saphire-1.1.1/saphire_debug.h <==
/*
 * fobOp[`
 */

#ifndef MINATO_DEBUG_H
#define MINATO_DEBUG_H

#include "saphire_extra.h"
#include <stdlib.h>

#ifndef MDEBUG

#   define CHECKML_BEGIN()
#   define CHECKML_END()  

#   define MALLOC(o) malloc(o)
#   define STRDUP(o) strdup(o)
#   define REALLOC(o, o2) realloc(o, o2)
#   define FREE(o) free(o)

#   define TIMER_BEGIN(msg)
#   define TIMER_END()

#else

/* [N`FbNp֐ */
void CheckMemLeak_Begin();      // 
void CheckMemLeak_End();        // 
ALLOC void* CheckMemLeak_Malloc(size_t size, const char* file_name, int line, const char* func_name);
    // [N`FbNpAP[g
ALLOC char* CheckMemLeak_Strdup(char* str, const char* file_name, int line, const char* func_name);
    // [N`FbNp񊄂蓖
ALLOC void* CheckMemLeak_Realloc(void* ptr, size_t size, const char* file_name, int line, const char* func_name);
    // [N`FbNpAbN
void CheckMemLeak_Free(MANAGED void* memory, const char* file_name, int line, const char* func_name);
    // [N`FbNpt[
 
void timer_count_start(char* msg);
void timer_count_end(const char* file, int line, const char* fun);

/* fobOp萔` */
#   define CHECKML_BEGIN() CheckMemLeak_Begin();
#   define CHECKML_END() CheckMemLeak_End(); 

#   define MALLOC(o) CheckMemLeak_Malloc(o, __FILE__, __LINE__, __FUNCTION__)
#   define STRDUP(o) CheckMemLeak_Strdup(o, __FILE__, __LINE__, __FUNCTION__)
#   define REALLOC(o, o2) CheckMemLeak_Realloc(o, o2, __FILE__, __LINE__, __FUNCTION__)
#   define FREE(o) CheckMemLeak_Free(o, __FILE__, __LINE__, __FUNCTION__)

#   define TIMER_BEGIN(msg) timer_count_start(msg)
#   define TIMER_END() timer_count_end(__FILE__, __LINE__, __FUNCTION__)

#endif

#endif

==> saphire-3.2.3.tgz: saphire-3.2.3/saphire_debug.h <==
/*
 * fobOp[`
 */

#ifndef MINATO_DEBUG_H
#define MINATO_DEBUG_H

#include "saphire_extra.h"
#include <stdlib.h>

#if defined(HAVE_GC_H) || defined(HAVE_GC_GC_H)

#ifdef HAVE_GC_H
#include <gc.h>
#endif

#ifdef HAVE_GC_GC_H
#include <gc/gc.h>
#endif

#   define CHECKML_BEGIN()
#   define CHECKML_END()  
#   define MALLOC(o) GC_malloc(o)
#   define STRDUP(o) GC_strdup(o)
#   define REALLOC(o, o2) GC_realloc(o, o2)
#   define FREE(o)
#   define TIMER_BEGIN(msg)
#   define TIMER_END()

#elif defined(MDEBUG)

/* [N`FbNp֐ */
void CheckMemLeak_Begin();      // 
void CheckMemLeak_End();        // 
ALLOC void* CheckMemLeak_Malloc(size_t size, const char* file_name, int line, const char* func_name);
    // [N`FbNpAP[g
ALLOC char* CheckMemLeak_Strdup(char* str, const char* file_name, int line, const char* func_name);
    // [N`FbNp񊄂蓖
ALLOC void* CheckMemLeak_Realloc(void* ptr, size_t size, const char* file_name, int line, const char* func_name);
    // [N`FbNpAbN
void CheckMemLeak_Free(MANAGED void* memory, const char* file_name, int line, const char* func_name);
    // [N`FbNpt[
 
void timer_count_start(char* msg);
void timer_count_end(const char* file, int line, const char* fun);

/* fobOp萔` */
#   define CHECKML_BEGIN() CheckMemLeak_Begin();
#   define CHECKML_END() CheckMemLeak_End(); 

#   define MALLOC(o) CheckMemLeak_Malloc(o, __FILE__, __LINE__, __FUNCTION__)
#   define STRDUP(o) CheckMemLeak_Strdup(o, __FILE__, __LINE__, __FUNCTION__)
#   define REALLOC(o, o2) CheckMemLeak_Realloc(o, o2, __FILE__, __LINE__, __FUNCTION__)
#   define FREE(o) CheckMemLeak_Free(o, __FILE__, __LINE__, __FUNCTION__)

#   define TIMER_BEGIN(msg) timer_count_start(msg)
#   define TIMER_END() timer_count_end(__FILE__, __LINE__, __FUNCTION__)

#else

#   define CHECKML_BEGIN()
#   define CHECKML_END()  
#   define MALLOC(o) malloc(o)
#   define STRDUP(o) strdup(o)
#   define REALLOC(o, o2) realloc(o, o2)
#   define FREE(o) free(o)
#   define TIMER_BEGIN(msg)
#   define TIMER_END()

#endif

#endif
